@@ -2,7 +2,7 @@
 
 . /etc/sysconfig/heat-params
 
-KUBE_OS_CLOUD_CONFIG=/etc/sysconfig/kube_openstack_config
+KUBE_OS_CLOUD_CONFIG=/etc/kubernetes/kube_openstack_config
 
 # Generate a the configuration for Kubernetes services
 # to talk to OpenStack Neutron
@@ -18,4 +18,6 @@ create-monitor=yes
 monitor-delay=1m
 monitor-timeout=30s
 monitor-max-retries=3
+[BlockStorage]
+bs-version=v2
 EOF
