@@ -55,7 +55,7 @@ class K8sFedoraTemplateDefinition(k8s_template_def.K8sTemplateDefinition):
     def __init__(self):
         super(K8sFedoraTemplateDefinition, self).__init__()
         self.add_parameter('docker_volume_size',
-                           cluster_template_attr='docker_volume_size')
+                           cluster_attr='docker_volume_size')
         self.add_parameter('docker_storage_driver',
                            cluster_template_attr='docker_storage_driver')
         self.add_output('kube_minions',
@@ -73,16 +73,27 @@ class K8sFedoraTemplateDefinition(k8s_template_def.K8sTemplateDefinition):
         osc = self.get_osc(context)
         extra_params['region_name'] = osc.cinder_region_name()
 
+        # set docker_volume_type
+        # use the configuration default if None provided
+        docker_volume_type = cluster_template.labels.get(
+            'docker_volume_type', CONF.cinder.default_docker_volume_type)
+        extra_params['docker_volume_type'] = docker_volume_type
+
+        kube_tag = cluster_template.labels.get('kube_tag')
+        if kube_tag:
+            extra_params['kube_tag'] = kube_tag
+
         return super(K8sFedoraTemplateDefinition,
                      self).get_params(context, cluster_template, cluster,
                                       extra_params=extra_params,
                                       **kwargs)
 
-    def get_env_files(self, cluster_template):
+    def get_env_files(self, cluster_template, cluster):
         env_files = []
 
         template_def.add_priv_net_env_file(env_files, cluster_template)
-        template_def.add_volume_env_file(env_files, cluster_template)
+        template_def.add_etcd_volume_env_file(env_files, cluster_template)
+        template_def.add_volume_env_file(env_files, cluster)
         template_def.add_lb_env_file(env_files, cluster_template)
         template_def.add_fip_env_file(env_files, cluster_template)
 
