@@ -12,7 +12,10 @@
 
 import mock
 
+from keystoneauth1 import exceptions as ka_exception
+
 from magnum.api.controllers.v1 import quota as api_quota
+from magnum.common import clients
 from magnum.tests import base
 from magnum.tests.unit.api import base as api_base
 from magnum.tests.unit.api import utils as apiutils
@@ -84,6 +87,20 @@ class TestQuota(api_base.FunctionalTest):
         res_proj_ids = [r['project_id'] for r in response['quotas']]
         self.assertEqual(sorted(expected), sorted(res_proj_ids))
 
+    @mock.patch("magnum.common.policy.enforce")
+    @mock.patch("magnum.common.context.make_context")
+    def test_get_all_with_non_admin_context(self, mock_context, mock_policy):
+        mock_context.return_value = self.context
+        quota_list = []
+        for i in range(4):
+            quota = obj_utils.create_test_quota(self.context,
+                                                project_id="proj-id-"+str(i))
+            quota_list.append(quota)
+
+        self.context.is_admin = False
+        response = self.get_json('/quotas?all_tenants=True')
+        self.assertEqual(0, len(response['quotas']))
+
     @mock.patch("magnum.common.policy.enforce")
     @mock.patch("magnum.common.context.make_context")
     def test_get_all_admin_not_all_tenants(self, mock_context, mock_policy):
@@ -141,6 +158,22 @@ class TestQuota(api_base.FunctionalTest):
         self.assertEqual(quota_list[-1].project_id,
                          response['quotas'][0]['project_id'])
 
+    @mock.patch("magnum.common.policy.enforce")
+    @mock.patch("magnum.common.context.make_context")
+    def test_get_all_admin_all_tenants_false(self, mock_context, mock_policy):
+        mock_context.return_value = self.context
+        quota_list = []
+        for i in range(4):
+            quota = obj_utils.create_test_quota(self.context,
+                                                project_id="proj-id-"+str(i))
+            quota_list.append(quota)
+
+        self.context.is_admin = True
+        self.context.project_id = 'proj-id-1'
+        response = self.get_json('/quotas?all_tenants=False')
+        self.assertEqual(1, len(response['quotas']))
+        self.assertEqual('proj-id-1', response['quotas'][0]['project_id'])
+
     def test_get_all_non_admin(self):
         quota_list = []
         for i in range(4):
@@ -153,14 +186,28 @@ class TestQuota(api_base.FunctionalTest):
         self.assertEqual(1, len(response['quotas']))
         self.assertEqual('proj-id-2', response['quotas'][0]['project_id'])
 
-    def test_create_quota(self):
+    @mock.patch.object(clients.OpenStackClients, 'keystone')
+    def test_create_quota(self, mock_keystone):
         quota_dict = apiutils.quota_post_data()
         response = self.post_json('/quotas', quota_dict)
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(201, response.status_int)
         self.assertEqual(quota_dict['project_id'], response.json['project_id'])
 
-    def test_create_quota_invalid_resource(self):
+    @mock.patch.object(clients.OpenStackClients, 'keystone')
+    def test_create_quota_project_id_not_found(self, mock_keystone):
+        keystone = mock.MagicMock()
+        exp = ka_exception.http.NotFound()
+        keystone.domain_admin_client.projects .get.side_effect = exp
+        mock_keystone.return_value = keystone
+        quota_dict = apiutils.quota_post_data()
+        response = self.post_json('/quotas', quota_dict, expect_errors=True)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(404, response.status_int)
+        self.assertTrue(response.json['errors'])
+
+    @mock.patch.object(clients.OpenStackClients, 'keystone')
+    def test_create_quota_invalid_resource(self, mock_keystone):
         quota_dict = apiutils.quota_post_data()
         quota_dict['resource'] = 'invalid-res'
         response = self.post_json('/quotas', quota_dict, expect_errors=True)
@@ -168,7 +215,8 @@ class TestQuota(api_base.FunctionalTest):
         self.assertEqual(400, response.status_int)
         self.assertTrue(response.json['errors'])
 
-    def test_create_quota_invalid_hard_limit(self):
+    @mock.patch.object(clients.OpenStackClients, 'keystone')
+    def test_create_quota_invalid_hard_limit(self, mock_keystone):
         quota_dict = apiutils.quota_post_data()
         quota_dict['hard_limit'] = -10
         response = self.post_json('/quotas', quota_dict, expect_errors=True)
@@ -176,7 +224,8 @@ class TestQuota(api_base.FunctionalTest):
         self.assertEqual(400, response.status_int)
         self.assertTrue(response.json['errors'])
 
-    def test_create_quota_no_project_id(self):
+    @mock.patch.object(clients.OpenStackClients, 'keystone')
+    def test_create_quota_no_project_id(self, mock_keystone):
         quota_dict = apiutils.quota_post_data()
         del quota_dict['project_id']
         response = self.post_json('/quotas', quota_dict, expect_errors=True)
@@ -184,7 +233,8 @@ class TestQuota(api_base.FunctionalTest):
         self.assertEqual(400, response.status_int)
         self.assertTrue(response.json['errors'])
 
-    def test_patch_quota(self):
+    @mock.patch.object(clients.OpenStackClients, 'keystone')
+    def test_patch_quota(self, mock_keystone):
         quota_dict = apiutils.quota_post_data(hard_limit=5)
         response = self.post_json('/quotas', quota_dict)
         self.assertEqual('application/json', response.content_type)
@@ -198,7 +248,8 @@ class TestQuota(api_base.FunctionalTest):
         self.assertEqual(202, response.status_int)
         self.assertEqual(20, response.json['hard_limit'])
 
-    def test_patch_quota_not_found(self):
+    @mock.patch.object(clients.OpenStackClients, 'keystone')
+    def test_patch_quota_not_found(self, mock_keystone):
         quota_dict = apiutils.quota_post_data()
         response = self.post_json('/quotas', quota_dict)
         self.assertEqual('application/json', response.content_type)
@@ -213,7 +264,8 @@ class TestQuota(api_base.FunctionalTest):
         self.assertEqual(404, response.status_int)
         self.assertTrue(response.json['errors'])
 
-    def test_delete_quota(self):
+    @mock.patch.object(clients.OpenStackClients, 'keystone')
+    def test_delete_quota(self, mock_keystone):
         quota_dict = apiutils.quota_post_data()
         response = self.post_json('/quotas', quota_dict)
         self.assertEqual('application/json', response.content_type)
