@@ -51,7 +51,12 @@ class TestClusterConductorWithK8s(base.TestCase):
                        'flannel_backend': 'vxlan',
                        'system_pods_initial_delay': '15',
                        'system_pods_timeout': '1',
-                       'admission_control_list': 'fake_list'},
+                       'admission_control_list': 'fake_list',
+                       'prometheus_monitoring': 'False',
+                       'grafana_admin_passwd': 'fake_pwd',
+                       'kube_dashboard_enabled': 'True',
+                       'docker_volume_type': 'lvmdriver-1',
+                       'etcd_volume_size': '0'},
             'tls_disabled': False,
             'server_type': 'vm',
             'registry_enabled': False,
@@ -70,6 +75,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'node_count': 1,
             'master_count': 1,
             'discovery_url': 'https://discovery.etcd.io/test',
+            'docker_volume_size': 20,
             'master_addresses': ['172.17.2.18'],
             'ca_cert_ref': 'http://barbican/v1/containers/xx-xx-xx-xx',
             'magnum_cert_ref': 'http://barbican/v1/containers/xx-xx-xx-xx',
@@ -149,7 +155,12 @@ class TestClusterConductorWithK8s(base.TestCase):
                        'flannel_backend': 'vxlan',
                        'system_pods_initial_delay': '15',
                        'system_pods_timeout': '1',
-                       'admission_control_list': 'fake_list'},
+                       'admission_control_list': 'fake_list',
+                       'prometheus_monitoring': 'False',
+                       'grafana_admin_passwd': 'fake_pwd',
+                       'kube_dashboard_enabled': 'True',
+                       'docker_volume_type': 'lvmdriver-1',
+                       'etcd_volume_size': '0'},
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
@@ -172,14 +183,19 @@ class TestClusterConductorWithK8s(base.TestCase):
             'number_of_minions': 1,
             'number_of_masters': 1,
             'docker_volume_size': 20,
+            'docker_volume_type': 'lvmdriver-1',
             'docker_storage_driver': 'devicemapper',
             'discovery_url': 'https://discovery.etcd.io/test',
+            'etcd_volume_size': '0',
             'flannel_network_cidr': '10.101.0.0/16',
             'flannel_network_subnetlen': '26',
             'flannel_backend': 'vxlan',
             'system_pods_initial_delay': '15',
             'system_pods_timeout': '1',
             'admission_control_list': 'fake_list',
+            'prometheus_monitoring': 'False',
+            'grafana_admin_passwd': 'fake_pwd',
+            'kube_dashboard_enabled': 'True',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
@@ -205,6 +221,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         self.assertEqual(expected, definition)
         self.assertEqual(
             ['../../common/templates/environments/no_private_network.yaml',
+             '../../common/templates/environments/no_etcd_volume.yaml',
              '../../common/templates/environments/with_volume.yaml',
              '../../common/templates/environments/no_master_lb.yaml',
              '../../common/templates/environments/disable_floating_ip.yaml',
@@ -252,6 +269,8 @@ class TestClusterConductorWithK8s(base.TestCase):
             'dns_nameserver': 'dns_nameserver',
             'docker_storage_driver': 'devicemapper',
             'docker_volume_size': 20,
+            'docker_volume_type': 'lvmdriver-1',
+            'etcd_volume_size': '0',
             'external_network': 'external_network_id',
             'fixed_network': 'fixed_network',
             'fixed_subnet': 'fixed_subnet',
@@ -261,6 +280,9 @@ class TestClusterConductorWithK8s(base.TestCase):
             'system_pods_initial_delay': '15',
             'system_pods_timeout': '1',
             'admission_control_list': 'fake_list',
+            'prometheus_monitoring': 'False',
+            'grafana_admin_passwd': 'fake_pwd',
+            'kube_dashboard_enabled': 'True',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'magnum_url': 'http://127.0.0.1:9511/v1',
@@ -292,6 +314,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         self.assertEqual(expected, definition)
         self.assertEqual(
             ['../../common/templates/environments/no_private_network.yaml',
+             '../../common/templates/environments/no_etcd_volume.yaml',
              '../../common/templates/environments/with_volume.yaml',
              '../../common/templates/environments/no_master_lb.yaml',
              '../../common/templates/environments/disable_floating_ip.yaml',
@@ -337,6 +360,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'auth_url': 'http://192.168.10.10:5000/v3',
             'cluster_uuid': '5d12f6fd-a196-4bf0-ae4c-1f639a523a52',
             'discovery_url': 'https://discovery.etcd.io/test',
+            'docker_volume_size': 20,
             'external_network': 'external_network_id',
             'flannel_backend': 'vxlan',
             'flannel_network_cidr': '10.101.0.0/16',
@@ -344,6 +368,11 @@ class TestClusterConductorWithK8s(base.TestCase):
             'system_pods_initial_delay': '15',
             'system_pods_timeout': '1',
             'admission_control_list': 'fake_list',
+            'prometheus_monitoring': 'False',
+            'grafana_admin_passwd': 'fake_pwd',
+            'kube_dashboard_enabled': 'True',
+            'docker_volume_type': 'lvmdriver-1',
+            'etcd_volume_size': '0',
             'insecure_registry_url': '10.0.0.1:5000',
             'kube_version': 'fake-version',
             'magnum_url': 'http://127.0.0.1:9511/v1',
@@ -364,7 +393,8 @@ class TestClusterConductorWithK8s(base.TestCase):
         self.assertEqual(expected, definition)
         self.assertEqual(
             ['../../common/templates/environments/with_private_network.yaml',
-             '../../common/templates/environments/no_volume.yaml',
+             '../../common/templates/environments/no_etcd_volume.yaml',
+             '../../common/templates/environments/with_volume.yaml',
              '../../common/templates/environments/no_master_lb.yaml',
              '../../common/templates/environments/disable_floating_ip.yaml',
              ],
@@ -410,6 +440,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'network_driver': 'network_driver',
             'volume_driver': 'volume_driver',
             'discovery_url': 'https://discovery.etcd.io/test',
+            'etcd_volume_size': '0',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
@@ -419,6 +450,9 @@ class TestClusterConductorWithK8s(base.TestCase):
             'system_pods_initial_delay': '15',
             'system_pods_timeout': '1',
             'admission_control_list': 'fake_list',
+            'prometheus_monitoring': 'False',
+            'grafana_admin_passwd': 'fake_pwd',
+            'kube_dashboard_enabled': 'True',
             'tls_disabled': False,
             'registry_enabled': False,
             'trustee_domain_id': self.mock_keystone.trustee_domain_id,
@@ -477,6 +511,7 @@ class TestClusterConductorWithK8s(base.TestCase):
             'network_driver': 'network_driver',
             'volume_driver': 'volume_driver',
             'discovery_url': 'http://tokentest/h1/h2/h3',
+            'etcd_volume_size': '0',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
@@ -486,6 +521,9 @@ class TestClusterConductorWithK8s(base.TestCase):
             'system_pods_initial_delay': '15',
             'system_pods_timeout': '1',
             'admission_control_list': 'fake_list',
+            'prometheus_monitoring': 'False',
+            'grafana_admin_passwd': 'fake_pwd',
+            'kube_dashboard_enabled': 'True',
             'tls_disabled': False,
             'registry_enabled': False,
             'trustee_domain_id': self.mock_keystone.trustee_domain_id,
@@ -668,8 +706,10 @@ class TestClusterConductorWithK8s(base.TestCase):
             'network_driver': 'network_driver',
             'volume_driver': 'volume_driver',
             'docker_volume_size': 20,
+            'docker_volume_type': 'lvmdriver-1',
             'docker_storage_driver': 'devicemapper',
             'discovery_url': 'https://address/token',
+            'etcd_volume_size': '0',
             'http_proxy': 'http_proxy',
             'https_proxy': 'https_proxy',
             'no_proxy': 'no_proxy',
@@ -679,6 +719,9 @@ class TestClusterConductorWithK8s(base.TestCase):
             'system_pods_initial_delay': '15',
             'system_pods_timeout': '1',
             'admission_control_list': 'fake_list',
+            'prometheus_monitoring': 'False',
+            'grafana_admin_passwd': 'fake_pwd',
+            'kube_dashboard_enabled': 'True',
             'tenant_name': 'fake_tenant',
             'username': 'fake_user',
             'cluster_uuid': self.cluster_dict['uuid'],
@@ -698,6 +741,7 @@ class TestClusterConductorWithK8s(base.TestCase):
         self.assertEqual(expected, definition)
         self.assertEqual(
             ['../../common/templates/environments/no_private_network.yaml',
+             '../../common/templates/environments/no_etcd_volume.yaml',
              '../../common/templates/environments/with_volume.yaml',
              '../../common/templates/environments/no_master_lb.yaml',
              '../../common/templates/environments/disable_floating_ip.yaml',
