@@ -260,6 +260,17 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
             'system_pods_timeout')
         admission_control_list = mock_cluster_template.labels.get(
             'admission_control_list')
+        prometheus_monitoring = mock_cluster_template.labels.get(
+            'prometheus_monitoring')
+        grafana_admin_passwd = mock_cluster_template.labels.get(
+            'grafana_admin_passwd')
+        kube_dashboard_enabled = mock_cluster_template.labels.get(
+            'kube_dashboard_enabled')
+        docker_volume_type = mock_cluster_template.labels.get(
+            'docker_volume_type')
+        etcd_volume_size = mock_cluster_template.labels.get(
+            'etcd_volume_size')
+        kube_tag = mock_cluster_template.labels.get('kube_tag')
 
         k8s_def = k8sa_tdef.AtomicK8sTemplateDefinition()
 
@@ -275,10 +286,16 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
             'system_pods_initial_delay': system_pods_initial_delay,
             'system_pods_timeout': system_pods_timeout,
             'admission_control_list': admission_control_list,
+            'prometheus_monitoring': prometheus_monitoring,
+            'grafana_admin_passwd': grafana_admin_passwd,
+            'kube_dashboard_enabled': kube_dashboard_enabled,
+            'docker_volume_type': docker_volume_type,
+            'etcd_volume_size': etcd_volume_size,
             'username': 'fake_user',
             'tenant_name': 'fake_tenant',
             'magnum_url': mock_osc.magnum_url.return_value,
-            'region_name': mock_osc.cinder_region_name.return_value}}
+            'region_name': mock_osc.cinder_region_name.return_value,
+            'kube_tag': kube_tag}}
         mock_get_params.assert_called_once_with(mock_context,
                                                 mock_cluster_template,
                                                 mock_cluster,
@@ -325,6 +342,17 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
             'system_pods_timeout')
         admission_control_list = mock_cluster_template.labels.get(
             'admission_control_list')
+        prometheus_monitoring = mock_cluster_template.labels.get(
+            'prometheus_monitoring')
+        grafana_admin_passwd = mock_cluster_template.labels.get(
+            'grafana_admin_passwd')
+        kube_dashboard_enabled = mock_cluster_template.labels.get(
+            'kube_dashboard_enabled')
+        docker_volume_type = mock_cluster_template.labels.get(
+            'docker_volume_type')
+        etcd_volume_size = mock_cluster_template.labels.get(
+            'etcd_volume_size')
+        kube_tag = mock_cluster_template.labels.get('kube_tag')
 
         k8s_def = k8sa_tdef.AtomicK8sTemplateDefinition()
 
@@ -340,12 +368,18 @@ class AtomicK8sTemplateDefinitionTestCase(BaseTemplateDefinitionTestCase):
             'system_pods_initial_delay': system_pods_initial_delay,
             'system_pods_timeout': system_pods_timeout,
             'admission_control_list': admission_control_list,
+            'prometheus_monitoring': prometheus_monitoring,
+            'grafana_admin_passwd': grafana_admin_passwd,
+            'kube_dashboard_enabled': kube_dashboard_enabled,
+            'docker_volume_type': docker_volume_type,
+            'etcd_volume_size': etcd_volume_size,
             'username': 'fake_user',
             'tenant_name': 'fake_tenant',
             'magnum_url': mock_osc.magnum_url.return_value,
             'region_name': mock_osc.cinder_region_name.return_value,
             'loadbalancing_protocol': 'HTTP',
-            'kubernetes_port': 8080}}
+            'kubernetes_port': 8080,
+            'kube_tag': kube_tag}}
         mock_get_params.assert_called_once_with(mock_context,
                                                 mock_cluster_template,
                                                 mock_cluster,
@@ -731,6 +765,8 @@ class AtomicSwarmTemplateDefinitionTestCase(base.TestCase):
         mock_context.user_name = 'fake_user'
         mock_context.tenant = 'fake_tenant'
 
+        docker_volume_type = mock_cluster_template.labels.get(
+            'docker_volume_type')
         flannel_cidr = mock_cluster_template.labels.get('flannel_network_cidr')
         flannel_subnet = mock_cluster_template.labels.get(
             'flannel_network_subnetlen')
@@ -750,7 +786,8 @@ class AtomicSwarmTemplateDefinitionTestCase(base.TestCase):
             'flannel_network_subnetlen': flannel_subnet,
             'auth_url': 'http://192.168.10.10:5000/v3',
             'rexray_preempt': rexray_preempt,
-            'swarm_strategy': swarm_strategy}}
+            'swarm_strategy': swarm_strategy,
+            'docker_volume_type': docker_volume_type}}
         mock_get_params.assert_called_once_with(mock_context,
                                                 mock_cluster_template,
                                                 mock_cluster,
