@@ -355,8 +355,8 @@ class TestObject(test_base.TestCase, _TestObject):
 # For more information on object version testing, read
 # http://docs.openstack.org/developer/magnum/objects.html
 object_data = {
-    'Cluster': '1.13-87f9b6ff2090663d69a1de2e95c50a27',
-    'ClusterTemplate': '1.17-65a95ef932dd08800a83871eb3cf312b',
+    'Cluster': '1.14-281c582b16291c4f0666371e53975a5c',
+    'ClusterTemplate': '1.17-f1ce5212b46506360b41ab5cb7658af4',
     'Certificate': '1.1-1924dc077daa844f0f9076332ef96815',
     'MyObj': '1.0-34c4b1aadefd177b13f9a2f894cc23cd',
     'X509KeyPair': '1.2-d81950af36c59a71365e33ce539d24f9',
@@ -427,7 +427,9 @@ class TestObjectSerializer(test_base.TestCase):
         primitive = obj.obj_to_primitive()
         result = ser.deserialize_entity(self.context, primitive)
         if backported_to is None:
-            self.assertFalse(mock_indirection_api.object_backport.called)
+            self.assertEqual(
+                False,
+                mock_indirection_api.object_backport.called)
         else:
             self.assertEqual('backported', result)
             mock_indirection_api.object_backport.assert_called_with(
